@@ -3,7 +3,7 @@ __all__ = 'get_htmls', 'is_request_correct'
 
 import asyncio
 import logging
-from typing import List
+from typing import List, Tuple
 
 import aiohttp
 import bs4
@@ -23,7 +23,7 @@ logger = clog.create_logger(
 
 async def fetch(url: str,
                 ses: aiohttp.ClientSession,
-                **kwargs) -> str:
+                **kwargs) -> Tuple[int, str]:
     """ Coro, obtaining page's html code. There's ClientTimeout.
 
     If response.status == 429 sleep and try again.
@@ -32,13 +32,13 @@ async def fetch(url: str,
     :param url: string, URL to get its html code.
     :param ses: aiohttp.ClientSession.
     :param kwargs: HTTP tags.
-    :return: html code, decoded to UTF-8.
+    :return: p key to sort results and html code, decoded to UTF-8.
     """
     wait = 24
     t_out = aiohttp.ClientTimeout(wait + 1)
     async with ses.get(url, params=kwargs, timeout=t_out) as resp:
         if resp.status == 200:
-            return await resp.text('utf-8')
+            return kwargs['p'], await resp.text('utf-8')
         elif resp.status == 429:
             await asyncio.sleep(wait)
             return await fetch(url, ses, **kwargs)
@@ -100,7 +100,10 @@ async def get_htmls_coro(url: str,
                     raise
                 else:
                     html_codes += [page_code]
+            # TODO: add pages' html codes as they are obtained
             # TODO: return here?
+            html_codes.sort(key=lambda x: x[0])
+            html_codes = [i[1] for i in html_codes]
             return html_codes
 
 
@@ -142,8 +145,8 @@ def is_http_request_correct(url: str,
     :param kwargs: request HTTP tags.
     :return: bool, correct the request or not.
     """
+    # coro writes logs by itself
     try:
-        # coro writes logs by itself
         get_htmls(url, **kwargs)
     except Exception:
         return False
@@ -154,10 +157,17 @@ def whether_result_found(url: str,
                          **kwargs) -> bool:
     """ Whether the page contains results.
 
+    RuntimeError if the request is wrong.
+
     :param url: str, request url.
     :param kwargs: request HTTP tags.
+    :exception RuntimeError: if HTTP request is wrong.
     """
-    page_html = get_htmls(url, **kwargs)[0]
+    try:
+        page_html = get_htmls(url, **kwargs)[0]
+    except Exception:
+        raise RuntimeError
+
     soup = bs4.BeautifulSoup(page_html, 'lxml')
 
     # TODO: сузить круг поиска
@@ -225,13 +235,13 @@ def is_request_correct(url: str,
     :return: True if everything's OK, an exception otherwise.
     :exception ValueError: something's wrong.
     """
-    # TODO: join 'is_http_request_correct' and 'whether_result_found'
-    # requesting coro writes log with exceptions by itself
-    if not is_http_request_correct(url, **kwargs):
-        raise ValueError("Wrong http req")
-
-    if not whether_result_found(url, **kwargs):
+    # coro writes logs by itself
+    try:
+        assert whether_result_found(url, **kwargs) is True
+    except AssertionError:
         raise ValueError("No results found")
+    except RuntimeError:
+        raise ValueError("Wrong HTTP request")
 
     if not does_page_exist(url, p_count - 1, **kwargs):
         raise ValueError("Last page doesn't exist")
